@@ -4,7 +4,7 @@ from typing import List, Optional
 
 import numpy as np
 
-from ..data_classes import Detections, ModelInformation
+from ..data_classes import ImageMetadata, ModelInformation
 from ..globals import GLOBALS
 
 
@@ -28,7 +28,7 @@ class DetectorLogic():
         return self._model_info is not None
 
     def load_model(self):
-        logging.info(f'Loading model from {GLOBALS.data_folder}/model')
+        logging.info('Loading model from %s', GLOBALS.data_folder)
         model_info = ModelInformation.load_from_disk(f'{GLOBALS.data_folder}/model')
         if model_info is None:
             logging.warning('No model found')
@@ -37,22 +37,22 @@ class DetectorLogic():
         try:
             self._model_info = model_info
             self.init()
-            logging.info(f'Successfully loaded model {self._model_info}')
+            logging.info('Successfully loaded model %s', self._model_info)
         except Exception:
-            logging.error(f'Could not init model {model_info}')
+            logging.error('Could not init model %s', model_info)
             raise
 
     @abstractmethod
     def init(self):
         """Called when a (new) model was loaded. Initialize the model. Model information available via `self.model_info`"""
 
-    def evaluate_with_all_info(self, image: np.ndarray, tags: List[str], source: Optional[str] = None) -> Detections:  # pylint: disable=unused-argument
+    def evaluate_with_all_info(self, image: np.ndarray, tags: List[str], source: Optional[str] = None, creation_date: Optional[str] = None) -> ImageMetadata:  # pylint: disable=unused-argument
         """Called by the detector node when an image should be evaluated (REST or SocketIO).
         Tags, source come from the caller and may be used in this function. 
         By default, this function simply calls `evaluate`"""
         return self.evaluate(image)
 
     @abstractmethod
-    def evaluate(self, image: np.ndarray) -> Detections:
+    def evaluate(self, image: np.ndarray) -> ImageMetadata:
         """Evaluate the image and return the detections.
         The object should return empty detections if it is not initialized"""
